@@ -82,7 +82,9 @@ Q_SIGNALS:
     void init();
 
     bool isEGLInitialized();
+    bool isStreamingEnabled();
 
+    void startStreamingInput();
     bool startStreaming(quint32 outputName);
     void stopStreaming();
 
